.. assemblyinfo documentation master file, created by
   sphinx-quickstart on Sat Jul  6 23:33:22 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

assemblyinfo
============

`Assemblyinfo <https://github.com/open2c/assemblyinfo>`_ is a library to interact with genome metadata from different providers in python. This package is build on top of NCBI and UCSC data, allowing fast and accurate interconversions between chromosome names, latest assemblies and more!

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart.md

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   tutorials/get_quick_stats.ipynb
   tutorials/retrieve_chromosome_data.ipynb
   tutorials/translate_chromosome_names.ipynb

.. toctree::
   :maxdepth: 3
   :caption: API

   api-core-accession
   api-core-assembly
   api-core-chromosome
   api-core-info
   api-build


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
